package com.lzmispt.data.resource.service.datasync.impl;

package .tmp;

import java.util.HashMap;
import java.util.Map;

public class FieldMappingTool {
  private static final String FLOAT = "float";
  
  private static final String NVARCHAR = "nvarchar";
  
  private static final String VARBINARY = "varbinary";
  
  private Map<String, String> mysqlToSqlServerMap;
  
  private Map<String, String> sqlServerToMysqlMap;
  
  private Map<String, String> pgsqlToMysqlMap;
  
  private Map<String, String> mysqlToPgsqlMap;
  
  private Map<String, String> pgsqlToSqlServerMap;
  
  private Map<String, String> sqlServerToPgsqlMap;
  
  private Map<String, String> pgsqlConvertMap;
  
  private static final String BIGINT = "bigint";
  
  private static final String TEXT = "text";
  
  private static final String SMALLINT = "smallint";
  
  private static final String INT = "int";
  
  private static final String DATE = "date";
  
  private static final String TIME = "time";
  
  public FieldMappingTool() {
    this.pgsqlToMysqlMap = new HashMap<>();
    this.mysqlToPgsqlMap = new HashMap<>();
    this.pgsqlToSqlServerMap = new HashMap<>();
    this.sqlServerToPgsqlMap = new HashMap<>();
    this.pgsqlConvertMap = new HashMap<>();
    buildMysqlToSqlServerMap();
    buildSqlServerToMysqlMap();
  }
  
  private void buildMysqlToSqlServerMap() {
    this.mysqlToSqlServerMap = new HashMap<>();
    this.mysqlToSqlServerMap.put("smallint", "smallint");
    this.mysqlToSqlServerMap.put("tinyint", "tinyint");
    this.mysqlToSqlServerMap.put("mediumint", "int");
    this.mysqlToSqlServerMap.put("int", "int");
    this.mysqlToSqlServerMap.put("bigint", "bigint");
    this.mysqlToSqlServerMap.put("decimal", "decimal");
    this.mysqlToSqlServerMap.put("float", "float");
    this.mysqlToSqlServerMap.put("float", "float(24)");
    this.mysqlToSqlServerMap.put("double", "float(53)");
    this.mysqlToSqlServerMap.put("char", "nchar");
    this.mysqlToSqlServerMap.put("varchar", "nvarchar");
    this.mysqlToSqlServerMap.put("tinytext", "nvarchar");
    this.mysqlToSqlServerMap.put("text", "nvarchar");
    this.mysqlToSqlServerMap.put("mediumtext", "nvarchar");
    this.mysqlToSqlServerMap.put("longtext", "nvarchar");
    this.mysqlToSqlServerMap.put("binary", "binary");
    this.mysqlToSqlServerMap.put("varbinary", "varbinary");
    this.mysqlToSqlServerMap.put("blob", "varbinary");
    this.mysqlToSqlServerMap.put("mediumblob", "varbinary");
    this.mysqlToSqlServerMap.put("longblob", "varbinary");
    this.mysqlToSqlServerMap.put("datetime", "datetime2");
    this.mysqlToSqlServerMap.put("date", "date");
    this.mysqlToSqlServerMap.put("time", "time");
    this.mysqlToSqlServerMap.put("smalldatetime", "smalldatetime");
    this.mysqlToSqlServerMap.put("year", "smallint");
  }
  
  private void buildSqlServerToMysqlMap() {
    this.sqlServerToMysqlMap = new HashMap<>();
    this.sqlServerToMysqlMap.put("bigint", "bigint");
    this.sqlServerToMysqlMap.put("binary", "binary");
    this.sqlServerToMysqlMap.put("bit", "tinyint");
    this.sqlServerToMysqlMap.put("char", "char");
    this.sqlServerToMysqlMap.put("date", "date");
    this.sqlServerToMysqlMap.put("datetime", "datetime");
    this.sqlServerToMysqlMap.put("datetime2", "datetime");
    this.sqlServerToMysqlMap.put("datetimeoffset", "datetime");
    this.sqlServerToMysqlMap.put("decimal", "decimal");
    this.sqlServerToMysqlMap.put("float", "float");
    this.sqlServerToMysqlMap.put("int", "int");
    this.sqlServerToMysqlMap.put("nchar", "char");
    this.sqlServerToMysqlMap.put("ntext", "text");
    this.sqlServerToMysqlMap.put("numeric", "decimal");
    this.sqlServerToMysqlMap.put("nvarchar", "varchar");
    this.sqlServerToMysqlMap.put("real", "float");
    this.sqlServerToMysqlMap.put("smallint", "smallint");
    this.sqlServerToMysqlMap.put("smallmoney", "float");
    this.sqlServerToMysqlMap.put("text", "text");
    this.sqlServerToMysqlMap.put("time", "time");
    this.sqlServerToMysqlMap.put("timestamp", "timestamp");
    this.sqlServerToMysqlMap.put("uniqueidentifier", "varchar");
    this.sqlServerToMysqlMap.put("varbinary", "varbinary");
    this.sqlServerToMysqlMap.put("varchar", "varchar");
    this.sqlServerToMysqlMap.put("xml", "text");
  }
  
  public String getSqlServerField(String mysqlField) {
    return this.mysqlToSqlServerMap.get(mysqlField);
  }
  
  public String getMysqlField(String sqlServerField) {
    return this.sqlServerToMysqlMap.get(sqlServerField);
  }
}
